@@ -195,6 +195,10 @@ static void load_pilot_portraits_palette(scene *scene) {
 static bool check_pilot_stat_cheat(scene *scene, int player_id) {
     melee_local *local = scene_get_userdata(scene);
 
+    if(local->network_game) {
+        return false;
+    }
+
     // if we haven't enabled the cheat yet, check the rules
     if(local->cheat_pilot_stats[player_id] != 0xFF) {
         if(local->cheat_pilot_stats[player_id] != 3)
@@ -859,18 +863,21 @@ int melee_event_cb(scene *scene, SDL_Event *e) {
     melee_local *local = scene_get_userdata(scene);
     if(local->page == HAR_SELECT && e->type == SDL_KEYDOWN && SDLK_1 <= e->key.keysym.sym &&
        e->key.keysym.sym <= SDLK_6) {
-        // color cheat:
-        // press 1-3 to change pilot1 colors
-        // press 4-6 to change pilot2 colors in 2 player
-        int idx = e->key.keysym.sym - SDLK_1;
-        int pal_id = idx % 3;
-        int player_id = idx / 3;
+        // Disable color selection until we figure it out properly
+        if(!local->network_game) {
+            // color cheat:
+            // press 1-3 to change pilot1 colors
+            // press 4-6 to change pilot2 colors in 2 player
+            int idx = e->key.keysym.sym - SDLK_1;
+            int pal_id = idx % 3;
+            int player_id = idx / 3;
 
-        game_player *player = game_state_get_player(scene->gs, player_id);
-        uint8_t color = sd_pilot_get_player_color(player->pilot, pal_id);
-        color = (color + 1) % 16;
-        sd_pilot_set_player_color(player->pilot, pal_id, color);
-        palette_load_player_colors(&player->pilot->palette, player_id);
+            game_player *player = game_state_get_player(scene->gs, player_id);
+            uint8_t color = sd_pilot_get_player_color(player->pilot, pal_id);
+            color = (color + 1) % 16;
+            sd_pilot_set_player_color(player->pilot, pal_id, color);
+            palette_load_player_colors(&player->pilot->palette, player_id);
+        }
     }
     return 1;
 }
